<?php

namespace Litecms\Trading\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Trading\Http\Requests\TradingSettingRequest;
use Litecms\Trading\Interfaces\TradingSettingRepositoryInterface;
use Litecms\Trading\Models\TradingSetting;

/**
 * Resource controller class for trading_setting.
 */
class TradingSettingResourceController extends BaseController
{

    /**
     * Initialize trading_setting resource controller.
     *
     * @param type TradingSettingRepositoryInterface $trading_setting
     *
     * @return null
     */
    public function __construct(TradingSettingRepositoryInterface $trading_setting)
    {
        parent::__construct();
        $this->repository = $trading_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Trading\Repositories\Criteria\TradingSettingResourceCriteria::class);
    }

    /**
     * Display a list of trading_setting.
     *
     * @return Response
     */
    public function index(TradingSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Trading\Repositories\Presenter\TradingSettingPresenter::class)
                ->$function();
        }

        $trading_settings = $this->repository->paginate();

        return $this->response->title(trans('trading::trading_setting.names'))
            ->view('trading::trading_setting.index', true)
            ->data(compact('trading_settings'))
            ->output();
    }

    /**
     * Display trading_setting.
     *
     * @param Request $request
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function show(TradingSettingRequest $request, TradingSetting $trading_setting)
    {

        if ($trading_setting->exists) {
            $view = 'trading::trading_setting.show';
        } else {
            $view = 'trading::trading_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('trading::trading_setting.name'))
            ->data(compact('trading_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new trading_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TradingSettingRequest $request)
    {

        $trading_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('trading::trading_setting.name')) 
            ->view('trading::trading_setting.create', true) 
            ->data(compact('trading_setting'))
            ->output();
    }

    /**
     * Create new trading_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TradingSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $trading_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('trading::trading_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('trading/trading_setting/' . $trading_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/trading/trading_setting'))
                ->redirect();
        }

    }

    /**
     * Show trading_setting for editing.
     *
     * @param Request $request
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function edit(TradingSettingRequest $request, TradingSetting $trading_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('trading::trading_setting.name'))
            ->view('trading::trading_setting.edit', true)
            ->data(compact('trading_setting'))
            ->output();
    }

    /**
     * Update the trading_setting.
     *
     * @param Request $request
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function update(TradingSettingRequest $request, TradingSetting $trading_setting)
    {
        try {
            $attributes = $request->all();

            $trading_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('trading::trading_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('trading/trading_setting/' . $trading_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('trading/trading_setting/' . $trading_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the trading_setting.
     *
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function destroy(TradingSettingRequest $request, TradingSetting $trading_setting)
    {
        try {

            $trading_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('trading::trading_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('trading/trading_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('trading/trading_setting/' . $trading_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple trading_setting.
     *
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function delete(TradingSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('trading::trading_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('trading/trading_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/trading/trading_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted trading_settings.
     *
     * @param Model   $trading_setting
     *
     * @return Response
     */
    public function restore(TradingSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('trading::trading_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/trading/trading_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/trading/trading_setting/'))
                ->redirect();
        }

    }

}
